DependencyKind

Enum DependencyKind 

pub enum DependencyKind {
    FinishToStart,
    StartToStart,
    FinishToFinish,
    Preferred,
}
Nature of the relationship between a predecessor and a successor task.

Variants



FinishToStart

Successor cannot start until predecessor finishes successfully.



StartToStart

Successor cannot start until predecessor starts.



FinishToFinish

Successor cannot finish until predecessor finishes.



Preferred

Soft dependency: preferred but not enforced (hints for the scheduler).

Implementations

Source

impl DependencyKind

pub const fn label(self) -> &'static str

Returns a short label.

pub const fn all() -> &'static [DependencyKind]

Returns all variants.

pub const fn is_hard(self) -> bool

Returns true if this dependency kind is strictly enforced.