pub enum WebhookEvent {
WorkflowStarted,
WorkflowCompleted,
WorkflowFailed,
StepCompleted {
step_name: String,
},
StepFailed {
step_name: String,
},
}Expand description
Events that can trigger an outbound webhook notification.
Variants
WorkflowStarted
Fired when a workflow transitions to the running state.
WorkflowCompleted
Fired when a workflow reaches a terminal completed state.
WorkflowFailed
Fired when a workflow reaches a terminal failed state.
StepCompleted
Fired when a named workflow step (task) succeeds.
StepFailed
Fired when a named workflow step (task) fails.
Implementations
Sourceimpl WebhookEvent
impl WebhookEvent