WorkflowAudit

Struct WorkflowAudit 

pub struct WorkflowAudit { /* private fields */ }
Append-only audit log for all workflow runs.

Implementations

Source

impl WorkflowAudit

pub fn new() -> Self

Create an empty audit log.

pub fn record(&mut self, entry: WorkflowAuditEntry)

Append an entry to the audit log.

pub fn entries_for_run(&self, run_id: &str) -> Vec<&WorkflowAuditEntry>

Return all entries for a specific run, in insertion order.

pub fn recent(&self, n: usize) -> Vec<&WorkflowAuditEntry>

Return the most recent n entries across all runs.

pub fn total_entries(&self) -> usize

Total number of entries across all runs.

pub fn all_entries(&self) -> &[WorkflowAuditEntry]

All entries (insertion order).

pub fn by_event_type(&self, et: &AuditEventType) -> Vec<&WorkflowAuditEntry>

Entries filtered by event type.