pub struct ThrottleState {
pub active: usize,
pub queued: usize,
pub total_admitted: u64,
pub total_rejected: u64,
}Expand description
Current load snapshot used by the throttler.
Fields
active: usizeNumber of currently running executions.
queued: usizeNumber of executions waiting in the queue.
total_admitted: u64Total number of executions admitted since the throttler was created.
total_rejected: u64Total number of executions rejected / delayed.
Implementations
Sourceimpl ThrottleState
impl ThrottleState
Sourcepub fn utilisation(&self, capacity: usize) -> f64
pub fn utilisation(&self, capacity: usize) -> f64
Returns utilisation as a fraction [0.0, 1.0] relative to a capacity.
Sourcepub fn has_capacity(&self, capacity: usize) -> bool
pub fn has_capacity(&self, capacity: usize) -> bool
Returns true if there is room for at least one more execution
given the specified capacity.