Task dependency modelling for oximedia-workflow.
Provides DependencyKind classification, TaskDependency edges, and a
DependencyResolver that performs a topological sort to determine correct
execution order and parallelism opportunities.
Structs
- Dependency
Resolver - Resolves a set of
TaskDependencyedges into a topologically-sorted execution order, detecting cycles. - Task
Dependency - A directed edge from one task to another in a dependency graph.
Enums
- Dependency
Kind - Nature of the relationship between a predecessor and a successor task.