pub fn quick_simulate(dag: &WorkflowDag) -> Result<bool, DagError>Expand description
Helper to create a simple simulation for a DAG.
Returns a result indicating whether the workflow would complete successfully.
Errors
Returns DagError if the DAG contains a cycle.